#
# spec file for package QMPlay2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           QMPlay2
Version:        16.09.24
Release:        1.1
Summary:        A Qt based media player, streamer and downloader
License:        LGPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://qt-apps.org/content/show.php/QMPlay2?content=153339
Source:         https://github.com/zaps166/QMPlay2/releases/download/%{version}/QMPlay2-src-%{version}.tar.xz
# PATCH-FIX-UPSTREAM vs. Qt5.3 lrelease issue, read more at
# https://github.com/zaps166/QMPlay2/issues/10#issuecomment-186585268
Patch0:         QMPlay2-Qt53-lrelease.diff
#PATCH-FIX-OPENSUSE vs. Prostopleer extension that provides illegal audio.
Patch1:         QMPlay2-no-prostopleer.diff

%if 0%{?suse_version} > 1310
BuildRequires:  libqt5-linguist
%else
BuildRequires:  libqt5-qttools
%endif
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsidplayfp)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xv)
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     youtube-dl
Obsoletes:      %{name}-kde-integration <= %{version}

%description
%{name} is a video player, it can play and stream all formats supported by
ffmpeg and libmodplug (including J2B). It has an integrated Youtube browser.

%package        devel
Summary:        %{name} development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description    devel
It's a development package for %{name}.

%prep
%setup -q -n %{name}-src-%{version}
%if 0%{?suse_version} <= 1320
%patch0
%endif
%patch1

%build
export QT_SUFFIX="-qt5"
%if 0%{?suse_version} <= 1320
export QMAKE=/usr/bin/qmake$QT_SUFFIX
lrelease$QT_SUFFIX QMPlay2.pro
%endif
NOTERM=1 SYSTEM_BUILD=1 ./compile_unix `echo "%{?_smp_mflags}" | grep -o '[0-9]*'`

%install
mkdir -p %{buildroot}%{_prefix}
cp -R app/* %{buildroot}%{_prefix}

# Setting libs to system libdir instead of 'lib'.
%if "%{_lib}" == "lib64"
mv %{buildroot}/%{_prefix}/{lib,lib64}
mkdir -p %{buildroot}/%{_prefix}/lib
ln -s %{_libdir}/qmplay2 %{buildroot}/%{_prefix}/lib/qmplay2
%endif

# Let's use %%doc macro. AUTHORS & ChangeLog are required for help window
cd %{buildroot}/%{_datadir}/qmplay2
rm LICENSE README.md TODO

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc LICENSE README.md TODO
%{_bindir}/%{name}
%{_libdir}/qmplay2
%{_libdir}/libqmplay2.so
%{_prefix}/lib/qmplay2
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%if 0%{?suse_version} == 1315
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%endif
%{_datadir}/qmplay2
%{_mandir}/man?/%{name}.?.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}

%changelog
* Sun Sep 25 2016 dap.darkness@gmail.com
- Update to 16.09.24:
  * Use namespace on libmodplug -
    don't mix system and QMPlay2 modplug,
  * Fix screen saver inhibition regression.
* Thu Sep 22 2016 dap.darkness@gmail.com
- Update to 16.09.21:
  * Updated icon for YouTube quality button,
  * Fixed screen saver blocking behavior,
  * OpenGL2 bugfix.
* Mon Sep  5 2016 dap.darkness@gmail.com
- Update to 16.09.04:
  * Don't load subtitles which needs decoder without the decoder,
  * add checkbox to disable PBO in OpenGL2 module settings,
  * fix displaying multi-line graphical subtitles,
  * don't crop non-graphics subtitles on zoom,
  * add quality button in YouTube browser,
  * download "youtube-dl" if necessary,
  * get rid of "QtNetwork" module,
  * add MPEG-TS programs support.
* Sun Aug 21 2016 dap.darkness@gmail.com
- Update to 16.08.19:
  * Add key shortcuts editor to Settings (thanks Zamarin Arthur),
  * respect HTML tags in classic subtitles,
  * use scroll area for equalizer sliders,
  * add presets to equalizer,
  * playlist bugfix,
  * OpenGL2 bugfix.
- Updated QMPlay2-no-prostopleer.diff.
* Wed Jul 20 2016 dap.darkness@gmail.com
- Update to 16.07.20:
  * Don't fetch the stream url twice on add and play action,
  * move most settings Ui from C++ to Qt forms,
  * play the entire audio if playback has been finished,
  * block screen saver on full screen when only audio is playing,
  * add sharpness to video adjustment (OpenGL2 and VDPAU only),
  * add key bindings (currently only in settings file),
  * sort current group instead of entire playlist,
  * HW and SW filters settings in the same place,
  * rename video equalizer -> video adjustment,
  * fix OGG pictures for taglib 1.11 and newer,
  * fix bug in tag editor (non-Windows OS'es),
  * updated Russian translation (victorr2007),
  * fix downloading cover art from Last FM,
  * move OpenGL2 shaders to resources,
  * handle multimedia keys on Windows,
  * properly handle chained OGG files,
  * add sharpness shader to OpenGL2,
  * move online contents to GitHub,
  * add contributors tab,
  * bugfix.
* Thu Jul  7 2016 dap.darkness@gmail.com
- Update to 16.07.07:
  * Ubuntu Unity integration (MPRIS2 and shortcut groups),
  * added video equalizer to "Settings/Video filters",
  * new "Concept" icons by Alexey Varfolomeev,
  * updated Russian translation (victorr2007),
  * properly add many files containing tracks,
  * better detection of subtitles text codec,
  * handle audio parameters changes,
  * MPRIS2 and PLS fixes.
- Updated QMPlay2-no-prostopleer.diff.
* Sun Jul  3 2016 dap.darkness@gmail.com
- Update to 16.07.02:
  * update pause and buffered data info when demuxer is busy,
  * move "modules" directory from "share/qmplay2" to "lib/qmplay2",
  * allow file group and Audio CD tracks synchronization:
    + synchronize automatically when loading the same playlist,
    + synchronize automatically when loading Audio CD tracks,
    + on "F5" key,
  * show more warnings in VDPAU and appearance settings,
  * fixed colour in graphics subtitles (e.g. dvdsub),
  * reading files doesn't depend on FFmpeg module,
  * hide mouse cursor when cover image is visible,
  * updated Russian translation (victorr2007),
  * allow mouse wheel to change the volume,
  * show blurred covers as a background,
  * OpenGL2 now uses PBO if available,
  * bugfix.
- Man page was merged into upstream.
- Updated QMPlay2-no-prostopleer.diff.
* Sat Jun  4 2016 dap.darkness@gmail.com
- Update to 16.06.01:
  * diplaying and filtering all planar 8-bit YUV pixel formats,
  * allow to display only file names in playlist,
  * update Russian translation (victorr2007),
  * allow to detach from receiving commands,
  * allow to remember the repeat mode,
  * added random and repeat playback,
  * minor fixes in FPS and A/V sync,
  * support video size changes,
  * fix "rawvideo" playback,
  * bugfix.
- Added man page.
* Sat May  7 2016 dap.darkness@gmail.com
- Update to 16.05.06:
  * split muted icon to muted and not muted,
  * bugfix.
- Updated QMPlay2-no-prostopleer.diff.
* Mon May  2 2016 dap.darkness@gmail.com
- Update to 16.05.02:
  * fixed command line argument processing,
  * playlist uses floating-point variables for storing length,
  * added audio balance,
  * don't play next entry after playback error by default,
  * fix restoring dock widgets state and window geometry,
  * added YouTube playlists and subtitles,
  * restore mute state on start-up,
  * seeking improvements,
  * bugfix.
* Sun Apr 24 2016 dap.darkness@gmail.com
- Update to 16.04.23:
  * VDPAU decoder without VDPAU writer is now available,
  * added spherical view for video playback (Ctrl+3; OpenGL only),
  * added Simplified Chinese translation (king Lee),
  * move video filtering to separate thread,
  * added Yadif deinterlacing filter,
  * better frame skipping,
  * replay gain fixes,
  * bugfix.
- Updated QMPlay2-no-prostopleer.diff.
* Mon Mar 28 2016 dap.darkness@gmail.com
- Update to 16.03.24:
  * XVideo SHM and OpenGL2(Qt >= 5.6) bugfix,
  * Bob deint bugfix for odd video height/2.
* Sat Mar 12 2016 dap.darkness@gmail.com
- Update to 16.03.11:
  * updated Russian translation (victorr2007).
- Added QMPlay2-no-prostopleer.diff  because Prostopleer extension
  provides illegal audio.
* Wed Mar  9 2016 dap.darkness@gmail.com
- Update to 16.03.08:
  * feature: suspend the computer after playback is finished,
  * fix VA-API driver Intel >= 1.6.2 video filtering,
  * fix slow seeking on some slow network streams,
  * zero-copy demuxing and decoding (if possible),
  * updated Russian translation (victorr2007),
  * 90°/270° video rotation (OpenGL only),
  * visualization and VDPAU/DDraw bugfix,
  * feature: A-B Repeat,
  * OpenGL 2 bugfix.
* Sat Feb 20 2016 dap.darkness@gmail.com
- Added QMPlay2-Qt53-lrelease.diff and hack vs. Qt<=5.3 lrelease
  issue. Read more at https://github.com/zaps166/QMPlay2/issues/10
* Sun Feb 14 2016 dap.darkness@gmail.com
- Update to 16.02.08:
  * play multiple streams in FFmpeg,
  * move ungrouped playlist entry to the end of the playlist,
  * QOpenGLWindow and QOpenGLWidget are used instead of QGLWidget,
  * FFmpeg module can play e.g. v4l2 on Linux/BSD,
  * display icons on playlist for AudioCD and Chiptines,
  * updated German translation (Daniel Meiß-Wilhelm),
  * added Spanish translation (Pedro Álamo),
  * VDPAU and DirectDraw overlay fixes,
  * English is now default language,
  * bugfix.
* Mon Dec 28 2015 dap.darkness@gmail.com
- Update to 15.12.25:
  * KF5 Breeze style fixes in full screen;
  * OpenGL 2 bugfix.
- New requirements recommended by upstream.
- Removed QMPlay2-Qt51.diff.
* Tue Dec 22 2015 dap.darkness@gmail.com
- Added QMPlay2-Qt51.diff to fix openSUSE 13.1' default Qt 5.1
  build issue.
- Fixed translations absence.
* Sun Dec 20 2015 dap.darkness@gmail.com
- Update to 15.12.06 (changes since 15.10.18):
  * support for HEVC, VP8 and VP9 decoding in VA-API,
  * setting priorities of decoders and A/V outputs
    is now more convenient,
  * improve QOpenGLWidget performance,
  * support for HEVC decoding in VDPAU,
  * simple visualization shows RMS of displayed signal
    in side bars,
  * fixes in AudioCD module, so any tracks must be added again,
  * falling horizontal lines behave better in visualizations,
  * play next entry after playback error (as default),
  * removed console for Windows,
  * added chiptune playback,
  * fix decoding Bink Video,
  * bugfix.
* Mon Oct 19 2015 dap.darkness@gmail.com
- Update to 15.10.18 (changes since 15.10.03):
  * due to new libass, FontConfig is used only on 32-bit WinXP,
  * correct display information about buffered time and size,
  * DirectDraw improvements,
  * many minor fixes,
  * new OpenGL 2 module (with OpenGL|ES 2.0 support).
- Removed QMPlay2-arm-no-opengl.diff.
* Tue Oct  6 2015 dap.darkness@gmail.com
- Added QMPlay2-arm-no-opengl.diff vs. vs. arm build issue, see
  more at https://github.com/zaps166/QMPlay2/issues/6
* Sun Oct  4 2015 dap.darkness@gmail.com
- Update to 15.10.03 (changes since 15.08.12):
  * user can hide menu bar by pressing Alt+Ctrl+M
    or from "Widgets" context menu,
  * minimum and maximum frequency in equalizer can be changed,
  * basic WebVTT subtitles support (SRT module),
  * added preamp and dB tooltip to equalizer,
  * fixed possible deadlock in AudioCD,
  * small bugfix.
* Mon Jul 13 2015 dap.darkness@gmail.com
- Update to 15.08.12 (changes since 15.07.13):
  * deinterlacing fixes in VAApi,
  * MPRIS2 bugfix.
* Mon Jul 13 2015 dap.darkness@gmail.com
- Update to 15.07.13 (changes since 15.06.26):
  * fixed problem with playing video
    (sometimes video plays at maximum speed).
* Tue Jul  7 2015 cfarrell@suse.com
- license update: LGPL-3.0+
  According to website and COPYING this is LGPL-3.0+
* Fri Jul  3 2015 dap.darkness@gmail.com
- Update to 15.06.26 (changes since 15.06.06):
  * better VSync support for OpenGL video output;
  * minor bug fixes.
* Mon Jun  8 2015 dap.darkness@gmail.com
- Let's not support KDE4.
- Let's use Qt5.
* Sat Jun  6 2015 dap.darkness@gmail.com
- Update to 15.06.06 (changes since 15.05.30):
  * more panel changes for touch screens;
  * zoom on a touch screen (pinch gesture);
  * fixed reading disk cover from the directory;
  * compatible with FFMpeg 2.0 and 2.1;
  * AudioCD as a separate module.
* Sun May 31 2015 dap.darkness@gmail.com
- Update to 15.05.30 (changes since 15.05.10):
  * drag and drop in the playlist was improved;
  * playlist loading became faster;
  * operations on directories were improved;
  * minor bug fixing.
- Packman → OBS.
- _service → tarball.
* Sun May 10 2015 dap.darkness@gmail.com
- Update to 15.05.10 (changes since 15.03.28):
  * YouTube search was fixed.
* Sun Mar 29 2015 dap.darkness@gmail.com
- Update to 15.03.28 (changes since 14.12.28):
  * exit the window via the mouse in fullscreen mode causes
    the closing of all widgets;
  * option to select the default language for subtitles and audio;
  * HttpReader FileReader and replaced by FFReader;
  * support for additional YouTube formats;
  * changes to the default windows configuration;
  * changes in the "Information" window;
  * amendments in the pgssub credits;
  * ability to save groups;
  * FFMpeg 2.6 support;
  * minor bug fixing.
* Mon Dec 29 2014 dap.darkness@gmail.com
- Update to 14.12.28 (changes since 14.12.23):
  * fixed fonts loading from folders with subtitles
    (not recursively);
  * the main toolbar can be split out from the main window;
  * fixed crash if built with AVResample;
  * fixed names displaying at YouTube playlist;
  * minor bug fixing.
* Sat Dec 27 2014 dap.darkness@gmail.com
- Update to 14.12.23 (changes since 14.12.01):
  * fixed playing stopping during operation `youtube-dl`,
    as well as with protocols other than HTTP and HTTPS;
  * ability to rewind streams network without reconnecting to the server;
  * Support MPRIS2 songs titles, even if they do not contain a header;
  * removed the ability to upgrade in systems other than Windows;
  * automatic program updates `youtube-dl`;
  * minor fixes search in YouTube;
  * added cache for a class of parameters;
  * improved caching.
* Tue Dec  2 2014 dap.darkness@gmail.com
- Update to 14.12.01 (changes since 14.10.07):
  * subtitles fonts loading from the directory,
    that provides ASS/SSA subtitles;
  * added "User-Agent" for HTTP connections
    (ProstoPleer working again);
  * minor bug fixing.
* Tue Oct  7 2014 dap.darkness@gmail.com
- Update to 14.10.07 (changes since 14.07.27):
  * the action of ASS subtitles restoring
    from Matroska container in FFMpeg 2.4.x;
  * metadata changes support for using FFMpeg 2.4.x;
  * saving equalizer settings video;
  * added to the playlist directories sorting;
  * improved work with YouTube;
  * added support for pleer.com;
  * improved OpenGL operation;
  * bug fixes.
* Mon Jul 28 2014 dap.darkness@gmail.com
- Update to 14.07.27 (changes since 14.03.05):
  * icons can be loaded from the system icon set;
  * added new icons,
  * any video site support through via `youtube-dl`;
  * noise, sharpness, and levels of zoom filters support in VDPAU;
  * ability to block widgets
    (removes the header row and blocks the toolbar);
  * ability to load modules from a directory settings
    (about/.qmplay2/Modules);
  * ability to customize colors and Wallpaper (as in QMPlay1);
  * reading/recording-playing improvements;
  * changed the way to save window position;
  * thread switching was improved;
  * MPRIS2 support;
  * image files, OGG support;
  * minor fixes in HttpReader;
  * VDPAU improvement;
  * service HTTPS improvement;
  * other small changes;
  * bug fixes.
* Thu Mar  6 2014 dap.darkness@gmail.com
- Update to 14.03.05 (changes since 14.02.17):
  * Improvement of the functionality of the YouTube
    service in the framework of the program "youtube-dl"
    (the path must be entered in the options);
  * The name of the disk AudioCD appears as an album;
  * OSD update bug was fixed;
  * Tags editing bug was fixed.
* Mon Feb 17 2014 dap.darkness@gmail.com
- Update to 14.02.17 (changes since 14.01.10):
  * CDDB database support was added;
    (freedb.org, freedb.musicbrainz.org);
  * Tags could be edited via taglib library;
  * Various issues associated with VAApi were fixed;
  * Fast switching tracks in AudioCD was implemented;
  * Minor bugs in FFDecSW were fixed;
  * Echo effect was added;
  * Minor fixes.
* Thu Jan 16 2014 dap.darkness@gmail.com
- Update to 14.01.10 (changes since 14.01.05):
  * Added support for algorithms that eliminates
    Intel VAApi card (VAEntrypointVideoProc);
  * Fixed a lot of VAApi errors;
  * Minor fixes in the code.
* Mon Jan  6 2014 dap.darkness@gmail.com
- Update to 14.01.05 (changes since 14.01.03):
  * Optional possibility of preview decoding through VDPAU;
  * Fixed building with the old version of alsa-lib;
  * The ability to playback in random order in the group;
  * Improved VAApi performance and stability;
  * Minor fixes in "VDPAU Writer.
* Fri Jan  3 2014 dap.darkness@gmail.com
- Update to 14.01.03 (changes since 13.12.15):
  * Method processParams () from "PrepareForHWBobDeint" was fixed;
  * Automatic search for the correct settings for sound;
  * Ability to add your own radio stations;
  * Improved modules ALSA and PortAudio;
  * Fixed a bug in ALSA plugin because of bad sound cards;
  * Added German translation (Daniel Meiß-Wilhelm);
  * "Playback setting" menu was fixed;
  * Possibility to save the skin;
  * Minor code fixes.
- pkgconfig(alsa) >= 1.0.26 became required to prevent build issue.
* Sun Dec 15 2013 dap.darkness@gmail.com
- Update to 13.12.15 (changes since 13.12.07):
  * Added ability to set the tabs at the top of the main window;
  * Added ability to select the audio channel in the Playback menu;
  * Restoration of validity HWAccel with FFMpeg 1.2;
  * Minor Bug fixes.
* Sun Dec  8 2013 dap.darkness@gmail.com
- Update to 13.12.07 (changes since 13.10.24):
  * Window will be opened automatically when the movie opens;
  * Shuffles play songs without repetitions;
  * Allows only one instance;
  * Bug fixes.
* Wed Oct 30 2013 dap.darkness@gmail.com
- Update to 13.10.24 (changes since 13.09.08):
  * actual number of frames per second representation;
  * OSD in DirectDraw improved;
  * LastFM support;
  * connections through a proxy server support;
  * display OSD in XVideo and DirectDraw improved;
  * hardware decoding via VDPAU added;
  * OSD display optimization;
  * ALSA module improved;
  * bug fixes.
- Spec-file was fixed up via `spec-cleaner`.
- KDE integration subpackage was added.
* Wed Sep 11 2013 fisiu@opensuse.org
- Update to 13.09.08 (changes since 13.08.18):
  * support SHOUTcast titles
  * ALSA output support
  * allow to setup decoders priority
  * new sound filter - phase reverse
  * fix WMA audio playback
  * fix video display using openGL and XVideo
  * many minor fixes
* Tue Sep  3 2013 obs@botter.cc
- add kdebase4-workspace to buildrequires to add KDE default action
* Sun Sep  1 2013 dap.darkness@gmail.com
- Initial build.
